@@ -16,7 +16,7 @@ def cmd_prioritize(args: argparse.Namespace) -> list[str]:
         cost=csv["cost"],
         duration=csv["duration"],
         risk=csv["risk"],
-        rigging=csv["rigging"],
+        pick=csv["pick"],
         alternatives=csv["alternative"],
         max_cost=args.budget,
         cost_per_duration=args.cost_per_duration,
@@ -107,7 +107,7 @@ def create_subparser_estimate(subparsers: argparse._SubParsersAction) -> None:
         "--simulations",
         type=int,
         nargs="?",
-        default=100000,
+        default=10000,
         help="Number of simulations to run",
     )
 
@@ -128,7 +128,7 @@ def create_subparser_guesstimate(subparsers: argparse._SubParsersAction) -> None
         "--simulations",
         type=int,
         nargs="?",
-        default=100000,
+        default=10000,
         help="Number of simulations to run",
     )
 
